[![PyPI version](https://badge.fury.io/py/matrixprofile-ts.svg)](https://badge.fury.io/py/matrixprofile-ts)
# matrixprofile-ts

## What is it?
matrixprofile-ts is a Python 3 library for evaluating time series data using the matrix profile algorithms developed by the Keough and Mueen research groups at the University of California-Riverside and the University of New Mexico. Current algorithms implemented include MASS, STMP, STAMP and STAMPI.

## Getting Started with Matrix Profile

### Installation
matrixprofile-ts is available on pip:

`pip install matrixprofile-ts`


### Tutorial
The GitHub repo includes a Jupyter Notebook tutorial containing basic examples of using matrix profile (see the docs folder). This notebook also renders automatically on the GitHub website.



### Matrix Profile Citations
Chin-Chia Michael Yeh, Yan Zhu, Liudmila Ulanova, Nurjahan Begum, Yifei Ding, Hoang Anh Dau, Diego Furtado Silva, Abdullah Mueen, Eamonn Keogh (2016). Matrix Profile I: All Pairs Similarity Joins for Time Series: A Unifying View that Includes Motifs, Discords and Shapelets. IEEE ICDM 2016. (http://www.cs.ucr.edu/~eamonn/MatrixProfile.html)
